This function retrieves the coefficients from a x object, formats them
with appropriate names, and rounds each coefficient to the specified number of decimal places.
Optionally, the intercept can be included or excluded from the output.
extract_coefs(x, digit = 3)A named numeric vector of model coefficients, rounded to the specified number of decimal places.
A model object generated from catalytic that containing model coefficients.
An integer specifying the number of decimal places for rounding coefficients. Default is 3.