This function adjusts the categorical initialization by creating a model frame for the predictors specified in the right-hand side of the formula and splits the adjusted data into observed and synthetic parts.
get_adjusted_cat_init(cat_init, formula_rhs)A list containing the original cat_init with added components:
- adj_x: The adjusted model frame for the predictors.
- adj_obs_x: The observed part of the adjusted predictors.
- adj_syn_x: The synthetic part of the adjusted predictors.
The object generated from cat_glm_initialization, cat_cox_initialization or cat_lmm_initialization
A formula specifying the right-hand side of the model for predictors.