This function calculates the linear predictor (LP) for new data points based on a fitted linear mixed model (LMM) stored in object.
# S3 method for cat_lmm
predict(object, newdata = NULL, ...)A vector of linear predictor values for the specified new data.
A fitted model object of class cat_lmm, containing the LMM fit and model details.
An optional data frame with new predictor values. If NULL,
the function uses the observation data from the model's initialization object.
Additional arguments passed to other functions.